@@ -11,17 +11,10 @@ EOF;
 $finder = PhpCsFixer\Finder::create()
     ->files()
     ->in(__DIR__ . '/src')
-    ->in(__DIR__ . '/tests/basic')
-    ->in(__DIR__ . '/tests/end-to-end')
-    ->in(__DIR__ . '/tests/fail')
-    ->in(__DIR__ . '/tests/unit')
     ->in(__DIR__ . '/tests/_files')
-    ->notName('*.phpt')
-    ->notName('ClassWithAllPossibleReturnTypes.php')
-    ->notName('ClassWithUnionReturnTypes.php')
-    ->notName('ClassWithStaticReturnTypes.php')
-    ->notName('ValueObjectWithEqualsMethodWithUnionReturnType.php')
-    ->notName('ValueObjectWithEqualsMethodThatHasUnionParameterType.php');
+    ->in(__DIR__ . '/tests/end-to-end')
+    ->in(__DIR__ . '/tests/unit')
+    ->notName('*.phpt');
 
 $config = new PhpCsFixer\Config;
 $config->setFinder($finder)
@@ -130,7 +123,10 @@ $config->setFinder($finder)
         'native_function_casing' => false,
         'native_function_invocation' => false,
         'native_function_type_declaration_casing' => true,
-        'new_with_braces' => false,
+        'new_with_braces' => [
+            'named_class' => false,
+            'anonymous_class' => false,
+        ],
         'no_alias_functions' => true,
         'no_alias_language_construct_call' => true,
         'no_alternative_syntax' => true,
