@@ -7,10 +7,14 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\Framework\MockObject;
+
+use function class_uses;
+use function func_get_args;
+use function get_class;
+use function get_parent_class;
+use Exception;
 use PHPUnit\Framework\ExpectationFailedException;
-use PHPUnit\Framework\MockObject\MockObject;
-use PHPUnit\Framework\MockObject\ReturnValueNotConfiguredException;
-use PHPUnit\Framework\MockObject\Stub;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\TestFixture\AbstractTrait;
 use PHPUnit\TestFixture\AnInterface;
@@ -21,16 +25,23 @@ use PHPUnit\TestFixture\ClassWithStaticMethod;
 use PHPUnit\TestFixture\ClassWithStaticReturnTypes;
 use PHPUnit\TestFixture\ClassWithUnionReturnTypes;
 use PHPUnit\TestFixture\ExampleTrait;
+use PHPUnit\TestFixture\Foo;
+use PHPUnit\TestFixture\FunctionCallbackWrapper;
 use PHPUnit\TestFixture\InterfaceWithMethodsThatDeclareBooleanReturnTypes;
 use PHPUnit\TestFixture\InterfaceWithStaticMethod;
 use PHPUnit\TestFixture\MethodCallback;
 use PHPUnit\TestFixture\MethodCallbackByReference;
 use PHPUnit\TestFixture\MockObject\AbstractMockTestClass;
+use PHPUnit\TestFixture\MockObject\InterfaceWithMethodReturningIntersection;
 use PHPUnit\TestFixture\PartialMockTestClass;
 use PHPUnit\TestFixture\SomeClass;
 use PHPUnit\TestFixture\StringableClass;
 use PHPUnit\TestFixture\TraitWithConstructor;
 use PHPUnit\TestFixture\TraversableMockTestInterface;
+use ReflectionObject;
+use RuntimeException;
+use stdClass;
+use Traversable;
 
 /**
  * @small
@@ -192,9 +203,9 @@ final class MockObjectTest extends TestCase
                      ->getMock();
 
         $mock->method('doSomething')
-             ->will($this->throwException(new \Exception));
+             ->will($this->throwException(new Exception));
 
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
 
         $mock->doSomething();
     }
@@ -205,9 +216,9 @@ final class MockObjectTest extends TestCase
                      ->getMock();
 
         $mock->method('doSomething')
-             ->willThrowException(new \Exception);
+             ->willThrowException(new Exception);
 
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
 
         $mock->doSomething();
     }
@@ -286,7 +297,10 @@ final class MockObjectTest extends TestCase
 
         $mock->expects($this->once())
              ->method('doSomething')
-             ->willReturnCallback('PHPUnit\TestFixture\FunctionCallbackWrapper::functionCallback');
+             ->will($this->returnCallback(sprintf(
+                 '%s::functionCallback',
+                 FunctionCallbackWrapper::class
+             )));
 
         $this->assertEquals('pass', $mock->doSomething('foo', 'bar'));
 
@@ -296,7 +310,10 @@ final class MockObjectTest extends TestCase
 
         $mock->expects($this->once())
              ->method('doSomething')
-             ->willReturnCallback('PHPUnit\TestFixture\FunctionCallbackWrapper::functionCallback');
+             ->willReturnCallback(sprintf(
+                 '%s::functionCallback',
+                 FunctionCallbackWrapper::class
+             ));
 
         $this->assertEquals('pass', $mock->doSomething('foo', 'bar'));
     }
@@ -377,7 +394,7 @@ final class MockObjectTest extends TestCase
         $mock2 = $this->getMockBuilder(AnInterface::class)
                      ->getMock();
 
-        $this->assertEquals(\get_class($mock1), \get_class($mock2));
+        $this->assertEquals(get_class($mock1), get_class($mock2));
     }
 
     public function testMockClassDifferentForPartialMocks(): void
@@ -401,14 +418,14 @@ final class MockObjectTest extends TestCase
                       ->onlyMethods(['doAnotherThing'])
                       ->getMock();
 
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock2));
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock3));
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock4));
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock5));
-        $this->assertEquals(\get_class($mock2), \get_class($mock3));
-        $this->assertNotEquals(\get_class($mock2), \get_class($mock4));
-        $this->assertNotEquals(\get_class($mock2), \get_class($mock5));
-        $this->assertEquals(\get_class($mock4), \get_class($mock5));
+        $this->assertNotEquals(get_class($mock1), get_class($mock2));
+        $this->assertNotEquals(get_class($mock1), get_class($mock3));
+        $this->assertNotEquals(get_class($mock1), get_class($mock4));
+        $this->assertNotEquals(get_class($mock1), get_class($mock5));
+        $this->assertEquals(get_class($mock2), get_class($mock3));
+        $this->assertNotEquals(get_class($mock2), get_class($mock4));
+        $this->assertNotEquals(get_class($mock2), get_class($mock5));
+        $this->assertEquals(get_class($mock4), get_class($mock5));
     }
 
     public function testMockClassStoreOverrulable(): void
@@ -432,15 +449,15 @@ final class MockObjectTest extends TestCase
                       ->setMockClassName('MyMockClassNameForPartialMockTestClass2')
                       ->getMock();
 
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock2));
-        $this->assertEquals(\get_class($mock1), \get_class($mock3));
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock4));
-        $this->assertNotEquals(\get_class($mock2), \get_class($mock3));
-        $this->assertNotEquals(\get_class($mock2), \get_class($mock4));
-        $this->assertNotEquals(\get_class($mock2), \get_class($mock5));
-        $this->assertNotEquals(\get_class($mock3), \get_class($mock4));
-        $this->assertNotEquals(\get_class($mock3), \get_class($mock5));
-        $this->assertNotEquals(\get_class($mock4), \get_class($mock5));
+        $this->assertNotEquals(get_class($mock1), get_class($mock2));
+        $this->assertEquals(get_class($mock1), get_class($mock3));
+        $this->assertNotEquals(get_class($mock1), get_class($mock4));
+        $this->assertNotEquals(get_class($mock2), get_class($mock3));
+        $this->assertNotEquals(get_class($mock2), get_class($mock4));
+        $this->assertNotEquals(get_class($mock2), get_class($mock5));
+        $this->assertNotEquals(get_class($mock3), get_class($mock4));
+        $this->assertNotEquals(get_class($mock3), get_class($mock5));
+        $this->assertNotEquals(get_class($mock4), get_class($mock5));
     }
 
     public function testGetMockWithFixedClassNameCanProduceTheSameMockTwice(): void
@@ -471,7 +488,7 @@ final class MockObjectTest extends TestCase
                       ->disableOriginalClone()
                       ->getMock();
 
-        $this->assertNotEquals(\get_class($mock1), \get_class($mock2));
+        $this->assertNotEquals(get_class($mock1), get_class($mock2));
     }
 
     /**
@@ -508,8 +525,8 @@ final class MockObjectTest extends TestCase
         $mock->expects($this->never())
              ->method('doSomething');
 
-        $parent = \get_parent_class($mock);
-        $traits = \class_uses($parent, false);
+        $parent = get_parent_class($mock);
+        $traits = class_uses($parent, false);
 
         $this->assertContains(AbstractTrait::class, $traits);
     }
@@ -598,7 +615,7 @@ final class MockObjectTest extends TestCase
                  $this->returnCallback(
                      static function () use (&$actualArguments): void
                      {
-                         $actualArguments = \func_get_args();
+                         $actualArguments = func_get_args();
                      }
                  )
              );
@@ -626,7 +643,7 @@ final class MockObjectTest extends TestCase
                  $this->returnCallback(
                      static function () use (&$actualArguments): void
                      {
-                         $actualArguments = \func_get_args();
+                         $actualArguments = func_get_args();
                      }
                  )
              );
@@ -716,9 +733,15 @@ final class MockObjectTest extends TestCase
             $mock->right(['second']);
         } catch (ExpectationFailedException $e) {
             $this->assertSame(
-                "Expectation failed for method name is \"right\" when invoked 1 time(s)\n" .
-                'Parameter 0 for invocation PHPUnit\TestFixture\SomeClass::right(Array (...)) does not match expected value.' . "\n" .
-                'Failed asserting that two arrays are equal.',
+                sprintf(
+                    <<<'EOF'
+Expectation failed for method name is "right" when invoked 1 time(s)
+Parameter 0 for invocation %s::right(Array (...)) does not match expected value.
+Failed asserting that two arrays are equal.
+EOF
+                    ,
+                    SomeClass::class
+                ),
                 $e->getMessage()
             );
         }
@@ -730,17 +753,24 @@ final class MockObjectTest extends TestCase
 //            $this->fail('Expected exception');
         } catch (ExpectationFailedException $e) {
             $this->assertSame(
-                "Expectation failed for method name is \"right\" when invoked 1 time(s).\n" .
-                'Parameter 0 for invocation PHPUnit\TestFixture\SomeClass::right(Array (...)) does not match expected value.' . "\n" .
-                'Failed asserting that two arrays are equal.' . "\n" .
-                '--- Expected' . "\n" .
-                '+++ Actual' . "\n" .
-                '@@ @@' . "\n" .
-                ' Array (' . "\n" .
-                '-    0 => \'first\'' . "\n" .
-                '-    1 => \'second\'' . "\n" .
-                '+    0 => \'second\'' . "\n" .
-                ' )' . "\n",
+                sprintf(
+                    <<<'EOF'
+Expectation failed for method name is "right" when invoked 1 time(s).
+Parameter 0 for invocation %s::right(Array (...)) does not match expected value.
+Failed asserting that two arrays are equal.
+--- Expected
++++ Actual
+@@ @@
+ Array (
+-    0 => 'first'
+-    1 => 'second'
++    0 => 'second'
+ )
+
+EOF
+                    ,
+                    SomeClass::class
+                ),
                 $e->getMessage()
             );
         }
@@ -763,7 +793,10 @@ final class MockObjectTest extends TestCase
             $this->fail('Expected exception');
         } catch (ExpectationFailedException $e) {
             $this->assertSame(
-                'PHPUnit\TestFixture\SomeClass::right() was not expected to be called.',
+                sprintf(
+                    '%s::right() was not expected to be called.',
+                    SomeClass::class
+                ),
                 $e->getMessage()
             );
         }
@@ -786,7 +819,10 @@ final class MockObjectTest extends TestCase
             $this->fail('Expected exception');
         } catch (ExpectationFailedException $e) {
             $this->assertSame(
-                'PHPUnit\TestFixture\SomeClass::right() was not expected to be called.',
+                sprintf(
+                    '%s::right() was not expected to be called.',
+                    SomeClass::class
+                ),
                 $e->getMessage()
             );
         }
@@ -809,9 +845,15 @@ final class MockObjectTest extends TestCase
             $this->fail('Expected exception');
         } catch (ExpectationFailedException $e) {
             $this->assertSame(
-                "Expectation failed for method name is \"right\" when invoked 1 time(s)\n" .
-                'Parameter count for invocation PHPUnit\TestFixture\SomeClass::right() is too low.' . "\n" .
-                'To allow 0 or more parameters with any value, omit ->with() or use ->withAnyParameters() instead.',
+                sprintf(
+                    <<<'EOF'
+Expectation failed for method name is "right" when invoked 1 time(s)
+Parameter count for invocation %s::right() is too low.
+To allow 0 or more parameters with any value, omit ->with() or use ->withAnyParameters() instead.
+EOF
+                    ,
+                    SomeClass::class
+                ),
                 $e->getMessage()
             );
         }
@@ -916,7 +958,7 @@ final class MockObjectTest extends TestCase
 
         $this->assertStringStartsWith(
             'Mock_WsdlMock_',
-            \get_class($mock)
+            get_class($mock)
         );
     }
 
@@ -929,7 +971,7 @@ final class MockObjectTest extends TestCase
 
         $this->assertStringStartsWith(
             'Mock_WsdlMock_',
-            \get_class($mock)
+            get_class($mock)
         );
     }
 
@@ -941,8 +983,8 @@ final class MockObjectTest extends TestCase
         $a = $this->getMockFromWsdl(TEST_FILES_PATH . 'GoogleSearch.wsdl');
         $b = $this->getMockFromWsdl(TEST_FILES_PATH . 'GoogleSearch.wsdl');
 
-        $this->assertStringStartsWith('Mock_GoogleSearch_', \get_class($a));
-        $this->assertEquals(\get_class($a), \get_class($b));
+        $this->assertStringStartsWith('Mock_GoogleSearch_', get_class($a));
+        $this->assertEquals(get_class($a), get_class($b));
     }
 
     /**
@@ -954,7 +996,7 @@ final class MockObjectTest extends TestCase
     {
         $mock = $this->getMockFromWsdl(TEST_FILES_PATH . 'Go ogle-Sea.rch.wsdl');
 
-        $this->assertStringStartsWith('Mock_GoogleSearch_', \get_class($mock));
+        $this->assertStringStartsWith('Mock_GoogleSearch_', get_class($mock));
     }
 
     /**
@@ -1023,7 +1065,6 @@ final class MockObjectTest extends TestCase
     {
         return [
             Traversable::class                  => [Traversable::class],
-            '\Traversable'                      => [Traversable::class],
             TraversableMockTestInterface::class => [TraversableMockTestInterface::class],
         ];
     }
@@ -1066,14 +1107,17 @@ final class MockObjectTest extends TestCase
                      ->getMock();
 
         $this->expectException(ReturnValueNotConfiguredException::class);
-        $this->expectExceptionMessage('Return value inference disabled and no expectation set up for PHPUnit\TestFixture\SomeClass::doSomethingElse()');
+        $this->expectExceptionMessage(sprintf(
+            'Return value inference disabled and no expectation set up for %s::doSomethingElse()',
+            SomeClass::class
+        ));
 
         $mock->doSomethingElse(1);
     }
 
     public function testDisableAutomaticReturnValueGenerationWithToString(): void
     {
-        /** @var PHPUnit\Framework\MockObject\MockObject|StringableClass $mock */
+        /** @var \PHPUnit\Framework\MockObject\MockObject|StringableClass $mock */
         $mock = $this->getMockBuilder(StringableClass::class)
             ->disableAutoReturnValueGeneration()
             ->getMock();
@@ -1085,7 +1129,10 @@ final class MockObjectTest extends TestCase
             $this->fail('Exception expected');
         } catch (RuntimeException $e) {
             $this->assertSame(
-                'Return value inference disabled and no expectation set up for PHPUnit\TestFixture\StringableClass::__toString()',
+                sprintf(
+                    'Return value inference disabled and no expectation set up for %s::__toString()',
+                    StringableClass::class
+                ),
                 $e->getMessage()
             );
         }
@@ -1229,6 +1276,18 @@ final class MockObjectTest extends TestCase
         $this->assertFalse($i->returnsBool());
     }
 
+    /**
+     * @requires PHP 8.1
+     */
+    public function testReturnValueCannotBeAutomaticallyGeneratedForMethodThatReturnsIntersection(): void
+    {
+        $stub = $this->createStub(InterfaceWithMethodReturningIntersection::class);
+
+        $this->expectException(\PHPUnit\Framework\MockObject\RuntimeException::class);
+
+        $stub->method();
+    }
+
     private function resetMockObjects(): void
     {
         $refl = new ReflectionObject($this);
