@@ -20,16 +20,16 @@ use function getcwd;
 use function ini_get;
 use function ini_set;
 use function trigger_error;
-use DependencyFailureTest;
 use DependencyInputTest;
-use DependencyOnClassTest;
-use DependencySuccessTest;
 use InvalidArgumentException;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\MockObject\Stub;
 use PHPUnit\Runner\BaseTestRunner;
 use PHPUnit\TestFixture\ChangeCurrentWorkingDirectoryTest;
 use PHPUnit\TestFixture\ClassWithScalarTypeDeclarations;
+use PHPUnit\TestFixture\DependencyFailureTest;
+use PHPUnit\TestFixture\DependencyOnClassTest;
+use PHPUnit\TestFixture\DependencySuccessTest;
 use PHPUnit\TestFixture\DoNoAssertionTestCase;
 use PHPUnit\TestFixture\ExceptionInAssertPostConditionsTest;
 use PHPUnit\TestFixture\ExceptionInAssertPreConditionsTest;
@@ -100,7 +100,10 @@ class TestCaseTest extends TestCase
     public function testCaseToString(): void
     {
         $this->assertEquals(
-            'PHPUnit\Framework\TestCaseTest::testCaseToString',
+            sprintf(
+                '%s::testCaseToString',
+                self::class
+            ),
             $this->toString()
         );
     }
@@ -875,9 +878,6 @@ class TestCaseTest extends TestCase
         $this->assertSame($expectedCwd, getcwd());
     }
 
-    /**
-     * @requires PHP 7
-     */
     public function testTypeErrorCanBeExpected(): void
     {
         $o = new ClassWithScalarTypeDeclarations;
@@ -1087,8 +1087,8 @@ class TestCaseTest extends TestCase
 
     public function testCanUseDependsToDependOnSuccessfulClass(): void
     {
-        $result = new TestResult();
-        $suite  = new TestSuite();
+        $result = new TestResult;
+        $suite  = new TestSuite;
         $suite->addTestSuite(DependencySuccessTest::class);
         $suite->addTestSuite(DependencyFailureTest::class);
         $suite->addTestSuite(DependencyOnClassTest::class);
@@ -1120,7 +1120,7 @@ class TestCaseTest extends TestCase
 
     public function testGetNameReturnsEmptyStringAsDefault(): void
     {
-        $testCase = new TestWithDifferentNames();
+        $testCase = new TestWithDifferentNames;
 
         $this->assertSame('', $testCase->getName());
     }
@@ -1133,7 +1133,10 @@ class TestCaseTest extends TestCase
         $testCase = new TestWithDifferentNames($name);
 
         $this->expectException(Exception::class);
-        $this->expectExceptionMessage('PHPUnit\Framework\TestCase::$name must be a non-blank string.');
+        $this->expectExceptionMessage(sprintf(
+            '%s::$name must be a non-blank string.',
+            TestCase::class
+        ));
 
         $testCase->runBare();
     }
@@ -1149,7 +1152,7 @@ class TestCaseTest extends TestCase
 
     public function testHasFailedReturnsFalseWhenTestHasNotRunYet(): void
     {
-        $test = new TestWithDifferentStatuses();
+        $test = new TestWithDifferentStatuses;
 
         $this->assertSame(BaseTestRunner::STATUS_UNKNOWN, $test->getStatus());
         $this->assertFalse($test->hasFailed());
