@@ -598,7 +598,13 @@ final class TestSuiteSorterTest extends TestCase
         $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_DEFAULT, false, TestSuiteSorter::ORDER_DEFAULT);
 
         $this->assertSame(EmptyTestCaseTest::class, $suite->tests()[0]->getName());
-        $this->assertSame('No tests found in class "PHPUnit\TestFixture\EmptyTestCaseTest".', $suite->tests()[0]->tests()[0]->getMessage());
+        $this->assertSame(
+            sprintf(
+                'No tests found in class "%s".',
+                EmptyTestCaseTest::class
+            ),
+            $suite->tests()[0]->tests()[0]->getMessage()
+        );
     }
 
     public function suiteSorterOptionPermutationsProvider(): array
